# coding: utf-8
# python setup.py sdist register upload
from distutils.core import setup

setup(
    name='sw-django-utils',
    version='0.0.14',
    description='Soft Way company django utils.',
    author='Telminov Sergey',
    url='https://github.com/telminov/sw-django-utils',
    packages=[
        'djutils',
        'djutils.views',
        'djutils.tests',
        'djutils.templatetags',
        'djutils.management',
        'djutils.management.commands',
    ],
    license='The MIT License',
    install_requires=[
        'django',
        'sqlparse==0.1.16',
    ],
)



# coding: utf-8
import json

from django import template
import sqlparse

register = template.Library()


@register.filter('pretty_sql')
def pretty_sql(sql):
    try:
        sql = sqlparse.format(sql, reindent=True, keyword_case='upper')
        return sql
    except Exception:
        return sql


@register.filter('pretty_json')
def pretty_json(json_text):
    try:
        pretty_json_text = json.dumps(json_text, indent=4)
        return pretty_json_text
    except Exception:
        return json_text
